import 'core-js/es6/array'
import format from 'string-template'
import extend from 'lodash/extend'
import assign from 'lodash/assign'
import { createClient } from 'contentful/dist/contentful.legacy.min.js'

let data
let client
let settings
const locale = navigator.languages ? navigator.languages[0] : (navigator.language || navigator.userLanguage)

const localeWithoutSuffix = locale => locale.split('-')[0]

const getEntries = (contentTypeId, lockedLocale) => client.getEntries({
  locale: lockedLocale || localeWithoutSuffix(locale),
  content_type: contentTypeId
})

const getFieldsWithIncludes = (contentTypeId, lockedLocale) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale)
  .then(({includes, items}) => {
    const includesFields = includes.Entry.map(({fields}) => fields)
    data = assign(...includesFields)
  })
  .then(() => {
    resolve(data)
  })
})

const getFields = (contentTypeId, lockedLocale) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale).then(({items}) => items.forEach(({fields}) => {
    data = fields
  })).then(() => {
    resolve(data)
  })
})

const VueContentful = {
  install (Vue, options) {
    settings = extend({
      space_id: null,
      access_token: null,
      content_type_id: null,
      lockLocaleTo: null
    }, options)

    Vue.prototype.$t = null

    client = createClient({
      space: settings.space_id,
      accessToken: settings.access_token
    })

    Vue.prototype.$getLangFields = contentTypeId => getFields(contentTypeId, settings.lockLocaleTo)
    Vue.prototype.$trans = (data, ...args) => format(data, ...args)
    Vue.prototype.$transChoice = (str, i, sep = ',') => str.split(sep)[i]
  },
  init (Vue) {
    return new Promise((resolve, reject) => {
      getFieldsWithIncludes(settings.content_type_id, settings.lockLocaleTo).then(() => {
        Vue.prototype.$t = data
        resolve(data)
      })
    })
  }
}

export default VueContentful
